package de.kompf.prefs;

import java.io.*;
import java.util.*;
import java.util.prefs.*;

/**
 * Demonstrate the usage of property files and the preferences API.
 */
public class PreferencesDemo {

  public void readPropertiesFile() throws IOException {
    Properties myProps = new Properties();
    try (InputStream inStream = ClassLoader.getSystemResourceAsStream("de/kompf/prefs/demo.properties")) {
      if (inStream != null) {
        myProps.load(inStream);
      }
    }

    String name = myProps.getProperty("name", "");
    int count = Integer.parseInt(myProps.getProperty("count", "0"));

    System.out.printf("%s %d%n", name, count);

    printAll(myProps);
  }

  public void printAll(Properties props) {
    for (Map.Entry<Object, Object> entry : props.entrySet()) {
      System.out.printf("%s = %s%n", entry.getKey(), entry.getValue());
    }
  }

  public void printAll(Preferences prefs) throws BackingStoreException {
    System.out.printf("Path: %s%n", prefs.absolutePath());
    for (String key : prefs.keys()) {
      System.out.printf("  %s = %s%n", key, prefs.get(key, "?"));
    }
    for (String child : prefs.childrenNames()) {
      printAll(prefs.node(child));
    }
  }

  public int readUserPreferences() {
    Preferences prefs = Preferences.userNodeForPackage(getClass());
    String name = prefs.get("name", "");
    int count = prefs.getInt("count", 0);

    System.out.printf("%s %d%n", name, count);
    return count;
  }

  public void writeUserPreferences(int count, String name) {
    Preferences prefs = Preferences.userNodeForPackage(getClass());

    prefs.put("name", name);
    prefs.putInt("count", count);
  }

  /**
   * @param args
   */
  public static void main(String[] args) throws IOException, BackingStoreException {
    PreferencesDemo demo = new PreferencesDemo();
    demo.readPropertiesFile();
    int count = demo.readUserPreferences();
    demo.writeUserPreferences(++count, "Test");
    demo.printAll(Preferences.userRoot());
  }
}
